@@ -5,13 +5,15 @@ from rest_framework import serializers
 from rest_framework.exceptions import ValidationError
 
 from .fields import ValidatedJSONField as ModelValidatedJSONField
-
+from .fields import ExtendedJsonValidatorWithDefault
 
 class ValidatedJSONField(serializers.JSONField):
     def __init__(self, *args, initial=None, validators=[], **kwargs):
         self.schema = kwargs.pop("schema")
         self.coreapi_schema = convert_to_openapi(copy.deepcopy(self.schema) )
-        self.json_validator_cls = kwargs.pop("json_validator_cls")
+        self.json_validator_cls = kwargs.pop("json_validator_cls", None)
+        if(self.json_validator_cls is None):
+            self.json_validator_cls = ExtendedJsonValidatorWithDefault(self.schema)
 
         #MIXING validators among multiple ModelValidatedJSONField, we should try not to use the validators argument
         def json_validator(value):
